@@ -44,12 +44,12 @@ sub save {
   my $self = shift;
   $self->saveZone;
   $self->saveInterface;
-  $self->saveFwNetworkPrivate;
   $self->saveAddress;
   $self->saveService;
   $self->saveRoute;
   $self->saveRule;
   $self->saveNat;
+  $self->saveFwNetworkPrivate;
 
   # 暂不支持
   # $self->saveSchedule;
@@ -69,17 +69,17 @@ sub saveZone {
   my $zoneExistsStatus = {new => {}, old => {}};
 
   # 遍历快照中的网络区域,写入 newZones 和 zoneExistsStatus
-  for my $zoneObj (values $self->{parser}{elements}{zone}->%*) {
+  for my $zoneObj (values %{$self->{parser}{elements}{zone}}) {
     my $zoneName = $zoneObj->{name};
     $newZones->{$zoneName} = undef;
     $zoneExistsStatus->{new}{$zoneName} = undef;
   }
 
   # 查询已有网络区域数据,写入 oldZones
-  $oldZones = $self->select(column => ['zone'], table => $tableName, where => {fw_id => $self->{parser}{fwId}})->all;
+  $oldZones = $self->select(column => ['zone'], table => $tableName, where => {fw_id => $self->fwId})->all;
 
   # 寻找差量数据
-  for my $zoneName (map { $_->{zone} } $oldZones->@*) {
+  for my $zoneName (map { $_->{zone} } @{$oldZones}) {
 
     # 新旧zones均存在,则不是新的数据
     if (exists $newZones->{$zoneName}) {
@@ -91,16 +91,16 @@ sub saveZone {
   }
 
   # 根据网络区域状态更新数据
-  if (keys $zoneExistsStatus->{new}->%* > 0) {
+  if (keys %{$zoneExistsStatus->{new}} > 0) {
     my $sql    = "insert into $tableName (fw_id, zone) values (?, ?)";
-    my $params = [map { [$self->fwId, $_] } keys $zoneExistsStatus->{new}->%*];
+    my $params = [map { [$self->fwId, $_] } keys %{$zoneExistsStatus->{new}}];
     $self->batchExecute($params, $sql);
   }
 
   # 设置 state 为 0 代表停用状态
-  if (keys $zoneExistsStatus->{old}->%* > 0) {
+  if (keys %{$zoneExistsStatus->{old}} > 0) {
     my $sql    = "update $tableName set state = 1 where fw_id = ? and zone = ?";
-    my $params = [map { [$self->fwId, $_] } keys $zoneExistsStatus->{old}->%*];
+    my $params = [map { [$self->fwId, $_] } keys %{$zoneExistsStatus->{old}}];
     $self->batchExecute($params, $sql);
   }
 }
@@ -119,7 +119,7 @@ sub saveInterface {
   my $params;
 
   # 编辑快照解析到的接口对象
-  for my $interface (values $self->{parser}{elements}{interface}->%*) {
+  for my $interface (values %{$self->{parser}{elements}{interface}}) {
 
     # 构造 SQL VALUES
     my @ints;
@@ -151,7 +151,7 @@ sub saveInterface {
     push @ints, $interface->{interfaceType};
 
     # 将数据压入 $params
-    push $params->@*, \@ints;
+    push @{$params}, \@ints;
   }
   $self->batchExecute($params, $sql);
 }
@@ -163,7 +163,7 @@ sub saveNat {
   my $self = shift;
 
   # 保存之前删除历史数据
-  $self->delete(where => {fw_id => $self->{parser}{fwId}}, table => "fw_nat_table");
+  $self->delete(where => {fw_id => $self->fwId}, table => "fw_nat_table");
 
   # 定义 sql 插入语句
   my $sql
@@ -174,13 +174,13 @@ sub saveNat {
   my $params;
 
   # 查询防火墙快照中的静态地址转换
-  for my $staticNat (values $self->{parser}{elements}{staticNat}->%*) {
+  for my $staticNat (values %{$self->{parser}{elements}{staticNat}}) {
 
     # 构造 SQL VALUES
     my @nat;
 
     # fw_id
-    push @nat, $self->{parser}{fwId};
+    push @nat, $self->fwId;
 
     # rule_id_name
     push @nat, $staticNat->{ruleName};
@@ -218,16 +218,16 @@ sub saveNat {
     push @nat, $staticNat->{config};
 
     # 将数据压入 params
-    push $params->@*, \@nat;
+    push @{$params}, \@nat;
   }
 
-  for my $dyNat (values $self->{parser}{elements}{dynamicNat}->%*) {
+  for my $dyNat (values %{$self->{parser}{elements}{dynamicNat}}) {
 
     # 构造 SQL VALUES
     my @nat;
 
     # fw_id
-    push @nat, $self->{parser}{fwId};
+    push @nat, $self->fwId;
 
     # rule_id_name
     push @nat, $dyNat->{ruleName};
@@ -281,7 +281,7 @@ sub saveNat {
     push @nat, $dyNat->{config};
 
     # 将数据压入 params
-    push $params->@*, \@nat;
+    push @{$params}, \@nat;
   }
   $self->batchExecute($params, $sql);
 }
@@ -303,7 +303,7 @@ sub saveRule {
   my $params;
 
   # 遍历解析到的防火墙策略
-  for my $rule (values $self->{parser}{elements}{rule}->%*) {
+  for my $rule (values %{$self->{parser}{elements}{rule}}) {
 
     # 构造 SQL VALUES
     my @rules;
@@ -323,9 +323,9 @@ sub saveRule {
     # to_zone
     push @rules, $rule->{toZone};
 
-    my @src = keys $rule->srcAddressMembers->%*;
-    my @dst = keys $rule->dstAddressMembers->%*;
-    my @srv = keys $rule->serviceMembers->%*;
+    my @src = keys %{$rule->{srcAddressMembers}};
+    my @dst = keys %{$rule->{dstAddressMembers}};
+    my @srv = keys %{$rule->{serviceMembers}};
 
     # source_addr
     push @rules, encode_json \@src;
@@ -356,13 +356,13 @@ sub saveRule {
     }
 
     # src_set
-    push @rules, encode_json {mins => $rule->srcAddressGroup->range->mins, maxs => $rule->srcAddressGroup->range->maxs};
+    push @rules, encode_json {mins => $rule->{srcAddressGroup}{range}{mins}, maxs => $rule->{srcAddressGroup}{range}{maxs}};
 
     # dst_set
-    push @rules, encode_json {mins => $rule->dstAddressGroup->range->mins, maxs => $rule->dstAddressGroup->range->maxs};
+    push @rules, encode_json {mins => $rule->{dstAddressGroup}{range}{mins}, maxs => $rule->{dstAddressGroup}{range}{maxs}};
 
     # srv_set
-    push @rules, encode_json {mins => $rule->serviceGroup->range->mins, maxs => $rule->serviceGroup->range->maxs};
+    push @rules, encode_json {mins => $rule->{serviceGroup}{range}{mins}, maxs => $rule->{serviceGroup}{range}{maxs}};
 
     # config
     push @rules, $rule->{content};
@@ -383,27 +383,27 @@ sub saveRule {
 
     # src_range
     my @src_range;
-    for (my $i = 0; $i < $rule->srcAddressGroup->range->mins->@*; $i++) {
-      push @src_range, "[" . $rule->srcAddressGroup->range->mins->[$i] . "," . $rule->srcAddressGroup->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{$rule->{srcAddressGroup}{range}{mins}}; $i++) {
+      push @src_range, "[" . $rule->{srcAddressGroup}{range}{mins}->[$i] . "," . $rule->{srcAddressGroup}{range}{maxs}->[$i] . "]";
     }
     push @rules, \@src_range;
 
     # dst_range
     my @dst_range;
-    for (my $i = 0; $i < $rule->dstAddressGroup->range->mins->@*; $i++) {
-      push @dst_range, "[" . $rule->dstAddressGroup->range->mins->[$i] . "," . $rule->dstAddressGroup->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{$rule->{dstAddressGroup}{range}->{mins}}; $i++) {
+      push @dst_range, "[" . $rule->{dstAddressGroup}{range}{mins}->[$i] . "," . $rule->{dstAddressGroup}{range}{maxs}->[$i] . "]";
     }
     push @rules, \@dst_range;
 
     # srv_range
     my @srv_range;
-    for (my $i = 0; $i < $rule->serviceGroup->range->mins->@*; $i++) {
-      push @srv_range, "[" . $rule->serviceGroup->range->mins->[$i] . "," . $rule->serviceGroup->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{$rule->{serviceGroup}{range}{mins}}; $i++) {
+      push @srv_range, "[" . $rule->{serviceGroup}{range}{mins}->[$i] . "," . $rule->{serviceGroup}{range}{maxs}->[$i] . "]";
     }
     push @rules, \@srv_range;
 
     # 将数据压入 params
-    push $params->@*, \@rules;
+    push @{$params}, \@rules;
   }
   $self->batchExecute($params, $sql);
 }
@@ -425,7 +425,7 @@ sub saveRoute {
   my $params;
 
   # 遍历解析到的路由条目
-  for my $route (values $self->{parser}{elements}{route}->%*) {
+  for my $route (values %{$self->{parser}{elements}{route}}) {
 
     # 构造 SQL VALUES
     my @route;
@@ -443,7 +443,7 @@ sub saveRoute {
     push @route, $route->{nextHop};
 
     # network_range
-    push @route, encode_json {maxs => $route->range->maxs, mins => $route->range->mins,};
+    push @route, encode_json {mins => $route->{range}{mins}, maxs => $route->{range}{maxs}};
 
     # distance
     push @route, $route->{distance};
@@ -468,7 +468,7 @@ sub saveRoute {
       $hash{srcInterface} = $route->{srcInterface} if defined $route->{srcInterface};
 
       # 路由关联 srcRange
-      $hash{srcRange} = {mins => $route->srcRange->mins, maxs => $route->srcRange->maxs} if defined $route->{srcRange};
+      $hash{srcRange} = {mins => $route->{srcRange}{mins}, maxs => $route->{srcRange}{maxs}} if defined $route->{srcRange};
 
       # 路由关联 routeInstance
       $hash{routeInstance} = $route->{routeInstance} if defined $route->{routeInstance};
@@ -480,13 +480,13 @@ sub saveRoute {
 
     # network_set
     my @network_set;
-    for (my $i = 0; $i < $route->range->mins->@*; $i++) {
-      push @network_set, "[" . $route->range->mins->[$i] . "," . $route->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{mins => $route->{range}{mins},}; $i++) {
+      push @network_set, "[" . $route->{range}{mins}->[$i] . "," . $route->{range}{maxs}->[$i] . "]";
     }
     push @route, \@network_set;
 
     # 将数据压入 params
-    push $params->@*, \@route;
+    push @{$params}, \@route;
   }
   $self->batchExecute($params, $sql);
 }
@@ -508,7 +508,7 @@ sub saveService {
   my $params;
 
   # 遍历解析到的服务端口对象
-  for my $serv (values $self->{parser}{elements}{service}->%*) {
+  for my $serv (values %{$self->{parser}{elements}{service}}) {
 
     # 构造 SQL VALUES
     my @serv;
@@ -526,17 +526,17 @@ sub saveService {
     push @serv, $serv->{config};
 
     # service_set
-    push @serv, encode_json {mins => $serv->range->mins, maxs => $serv->range->maxs};
+    push @serv, encode_json {mins => $serv->{range}{mins}, maxs => $serv->{range}{maxs}};
 
     # service_range
     my @service_range;
-    for (my $i = 0; $i < $serv->range->mins->@*; $i++) {
-      push @service_range, "[" . $serv->range->mins->[$i] . "," . $serv->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{$serv->{range}{mins}}; $i++) {
+      push @service_range, "[" . $serv->{range}{mins}->[$i] . "," . $serv->{range}{maxs}->[$i] . "]";
     }
     push @serv, \@service_range;
 
     # 将数据压入 $params
-    push $params->@*, \@serv;
+    push @{$params}, \@serv;
   }
   $self->batchExecute($params, $sql);
 }
@@ -558,7 +558,7 @@ sub saveAddress {
   my $params;
 
   # 遍历解析到的地址对象
-  for my $addr (values $self->{parser}{elements}{address}->%*) {
+  for my $addr (values %{$self->{parser}{elements}{address}}) {
 
     # 构造 SQL VALUES
     my @addr;
@@ -576,12 +576,12 @@ sub saveAddress {
     push @addr, $addr->{config};
 
     # address_set
-    push @addr, encode_json {mins => $addr->range->mins, maxs => $addr->range->maxs};
+    push @addr, encode_json {mins => $addr->{range}{mins}, maxs => $addr->{range}{maxs}};
 
     # address_range
     my @address_range;
-    for (my $i = 0; $i < $addr->range->mins->@*; $i++) {
-      push @address_range, "[" . $addr->range->mins->[$i] . "," . $addr->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{$addr->{range}{mins}}; $i++) {
+      push @address_range, "[" . $addr->{range}{mins}->[$i] . "," . $addr->{range}{maxs}->[$i] . "]";
     }
     push @addr, \@address_range;
 
@@ -589,11 +589,11 @@ sub saveAddress {
     push @addr, encode_json {zone => $addr->{zone}};
 
     # 压入数据到 $params
-    push $params->@*, \@addr;
+    push @{$params}, \@addr;
   }
 
   # 遍历地址组对象
-  for my $addrG (values $self->{parser}{elements}{addressGroup}->%*) {
+  for my $addrG (values %{$self->{parser}{elements}{addressGroup}}) {
 
     # 构造 SQL VALUES
     my @addr;
@@ -611,12 +611,12 @@ sub saveAddress {
     push @addr, $addrG->{config};
 
     # address_set
-    push @addr, encode_json {mins => $addrG->range->mins, maxs => $addrG->range->maxs};
+    push @addr, encode_json {mins => $addrG->{range}{mins}, maxs => $addrG->{range}{maxs}};
 
     # address_range
     my @address_range;
-    for (my $i = 0; $i < $addrG->range->mins->@*; $i++) {
-      push @address_range, "[" . $addrG->range->mins->[$i] . "," . $addrG->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < @{$addrG->{range}{mins}}; $i++) {
+      push @address_range, "[" . $addrG->{range}{mins}->[$i] . "," . $addrG->{range}{maxs}->[$i] . "]";
     }
     push @addr, \@address_range;
 
@@ -624,7 +624,7 @@ sub saveAddress {
     push @addr, encode_json {zone => $addrG->{zone}};
 
     # 将数据压入 $params
-    push $params->@*, \@addr;
+    push @{$params}, \@addr;
   }
   $self->batchExecute($params, $sql);
 }
@@ -655,12 +655,12 @@ sub updateNetwork {
     $self->delete(where => {fw_id => $self->fwId}, table => $table);
 
     # 遍历防火墙网络区域
-    foreach my $zone (keys $zones->%*) {
+    foreach my $zone (keys %{$zones}) {
 
       # 这里的变量基于 Set 顺序一致
-      my $addrIprange = $zones->{$zone}->addrIpRange;
-      my $mins        = $zones->{$zone}->mins;
-      my $maxs        = $zones->{$zone}->maxs;
+      my $addrIprange = $zones->{$zone}{addrIpRange};
+      my $mins        = $zones->{$zone}{mins};
+      my $maxs        = $zones->{$zone}{maxs};
 
       # COPY 复刻副本
       my $copy_addrIprange = dclone $addrIprange;
@@ -668,7 +668,7 @@ sub updateNetwork {
       my $copy_maxs        = dclone $maxs;
 
       # 遍历 addrIprange 数组
-      while ($copy_addrIprange->@*) {
+      while (@{$copy_addrIprange}) {
 
         # 初始化变量 @zone
         my @zone;
@@ -680,16 +680,16 @@ sub updateNetwork {
         push @zone, $zone;
 
         # addr_range
-        push @zone, pop $copy_addrIprange->@*;
+        push @zone, pop @{$copy_addrIprange};
 
         # addr_min
-        push @zone, pop $copy_mins->@*;
+        push @zone, pop @{$copy_mins};
 
         # addr_max
-        push @zone, pop $copy_maxs->@*;
+        push @zone, pop @{$copy_maxs};
 
         # 将数据压入 params
-        push $params->@*, \@zone;
+        push @{$params}, \@zone;
       }
     }
 
@@ -712,25 +712,25 @@ sub updateStaticNatToNetwork {
   my $sql = "insert into $table (fw_id,zone,addr_range,addr_min,addr_max) values(?,?,?,?,?)";
 
   # 查询防火墙快照中的静态地址转换
-  for my $staticNat (values $self->{parser}{elements}{staticNat}->%*) {
+  for my $staticNat (values %{$self->{parser}{elements}{staticNat}}) {
 
     # 这里的变量基于 Set 顺序一致
-    my $mins = $staticNat->natIpRange->mins;
-    my $maxs = $staticNat->natIpRange->maxs;
+    my $mins = $staticNat->{natIpRange}{mins};
+    my $maxs = $staticNat->{natIpRange}{maxs};
 
     # COPY 复刻副本 | 深度复刻、互不影响
     my $copy_mins = dclone $mins;
     my $copy_maxs = dclone $maxs;
 
     # 遍历 $mins 数组
-    while ($copy_mins->@*) {
+    while (@{$copy_mins}) {
 
       # 初始化变量 @network
       my @network;
 
       # 转换为 ipSet 集合 | 数据准备
-      my $min        = pop $copy_mins->@*;
-      my $max        = pop $copy_maxs->@*;
+      my $min        = pop @{$copy_mins};
+      my $max        = pop @{$copy_maxs};
       my $ipMin      = Firewall::Utils::Ip->new->changeIntToIp($min);
       my $ipMax      = Firewall::Utils::Ip->new->changeIntToIp($max);
       my $addr_range = $ipMin . "-" . $ipMax;
@@ -751,7 +751,7 @@ sub updateStaticNatToNetwork {
       push @network, $max;
 
       # 将数据压入 params
-      push $params->@*, \@network;
+      push @{$params}, \@network;
     }
     $self->batchExecute($params, $sql);
   }
@@ -794,7 +794,7 @@ sub saveFwNetworkPrivate {
 
     # 遍历防火墙相关网络区域
     my (@protected, @unProtected, @unUse);
-    for my $zone ($zoneInfo->@*) {
+    for my $zone (@{$zoneInfo}) {
       if (defined $zone->{is_protected_zone}) {
         if ($zone->{is_protected_zone} == 1) {
           push @protected, $zone->{zone};
@@ -816,11 +816,10 @@ sub saveFwNetworkPrivate {
         my $zones = $self->{parser}{elements}{zone};
         $self->updateNetwork($zones, 'fw_network_private', 'fw_network_main');
       };
-
-      # confess "批量更新防火墙大网、私网期间捕捉异常：$@" if defined $@;
+      confess "批量更新防火墙大网、私网期间捕捉异常：$@" if !!$@;
     }
     else {
-      my $zoneIndex = $self->{parser}->{elements}->{zone};
+      my $zoneIndex = $self->{parser}{elements}{zone};
       my $protectedZone;
       my $unprotectedZone;
 
